package cmsc420_f20;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.util.Scanner;

/**
 * Testing program for the XBSTree data structure.
 * 
 * Input may be read from standard input/output or from files. See the comments
 * below. This creates a new XBSTree and then invokes the CommandHandler to
 * process the commands.
 */
public class XBSTreeTester {

	// --------------------------------------------------------------------------------------------
	// Uncomment these to read from standard input and output
	// private static final boolean USE_STD_IO = true;
	// private static String inputFileName = "";
	// private static String outputFileName = "";
	// --------------------------------------------------------------------------------------------
	// Uncomment these to read from a file (USE THESE FOR YOUR TESTING ONLY)
	// --------------------------------------------------------------------------------------------
	private static final boolean USE_STD_IO = false;
	private static final String inFolder = "tests"; // folder with input files (from project root)
	private static final String outFolder = "tests"; // folder with output files (from project root)
	private static String[] inputFileList = { 
			"test01-input.txt",
			"test02-input.txt",
			"test03-input.txt",
			"test04-input.txt",
			"test05-input.txt",
			};
	private static String[] outputFileList = { 
			"test01-output.txt",
			"test02-output.txt",
			"test03-output.txt",
			"test04-output.txt",
			"test05-output.txt",
			};
	// --------------------------------------------------------------------------------------------

	public static void main(String[] args) {

		// configure to read from file rather than standard input/output
		if (!USE_STD_IO) {
			try {
				for (int m = 0; m < inputFileList.length; m++) {
					System.setIn(new FileInputStream(inFolder + "/" + inputFileList[m]));
					System.setOut(new PrintStream(outFolder + "/" + outputFileList[m]));
				
					processInput();
				}
			} catch (FileNotFoundException e) {
				e.printStackTrace();
			}
		}
		else {
			processInput();
		}
	}
	
	static void processInput() {
		// configure to read from file rather than standard input/output
		try {
			Scanner scanner = new Scanner(System.in); // input scanner
			XBSTree<String, Airport> xbsTree = new XBSTree<String, Airport>(); // create the tree
			CommandHandler commandHandler = new CommandHandler(xbsTree); // initialize command handler
			while (scanner.hasNextLine()) {
				String line = scanner.nextLine(); // input next line
				String output = commandHandler.processCommand(line); // process this command
				System.out.print(output); // output summary
			}
			scanner.close();
		} catch (Exception e) {
			System.err.println("Unexpected error: " + e.getMessage());
			e.printStackTrace(System.err);
		}
	}
}
